@@ -1,6 +1,6 @@
 # pylint: disable=attribute-defined-outside-init
 """ Functions for loading and saving files to disk. """
-import semver as SemVer
+import semver
 from box import Box
 import datetime
 from pathlib import Path
@@ -47,7 +47,7 @@ class MLObject(Box):
     """ Contains all the fields loaded from an MLSpec, and validated against the MLSchema. Also
     provides load and save functions."""
 
-    __version='0.0.1'
+    __version = '0.0.18'
 
     def set_type(self, schema_version, schema_type, schema=None, schema_object=None):
         """ Used primarily after MLObject instantiation to set the schema_version and
@@ -55,7 +55,7 @@ class MLObject(Box):
         with all fields set to 'None' except schema_version and schema_type."""
 
         try:
-            SemVer.parse(schema_version)
+            semver.VersionInfo.parse(schema_version)
             self.__schema_version = schema_version
         except ValueError:
             raise ValueError(f"'{schema_version}' is not a valid semantic version.")
@@ -125,7 +125,9 @@ class MLObject(Box):
     def validate(self):
         """ Returns an array of errors after validating against the assigned
         schema. Each error is an array with the message at the 0-th index."""
-        return self.get_schema().validate(self.dict_without_internal_variables())
+        schema = self.get_schema()
+        content_to_validate = self.dict_without_internal_variables()
+        return schema.validate(content_to_validate)
 
     def save(self, save_path: Path, export_json=False):
         """ Copies all internal data to an MLSchema, which it then
@@ -297,9 +299,11 @@ class MLObject(Box):
         #                                 schema_string, contents_as_dict['schema_type']))
 
         ml_object = MLObject()
+        schema_version = contents_as_dict["schema_version"]
+        schema_type = contents_as_dict["schema_type"]
         ml_object.set_type(
-            schema_version=contents_as_dict["schema_version"],
-            schema_type=contents_as_dict["schema_type"],
+            schema_version=schema_version,
+            schema_type=schema_type,
         )
         MLObject.update_tree(ml_object, contents_as_dict)
         errors = ml_object.validate()
